<?php
/*
Plugin Name: WooCommerce Popup Plugin
Description: Custom WooCommerce popups with individual delay, link options, button, image position settings (Top, Right, Bottom, Left), and "Show only once" functionality. The popup closes when clicked outside or on the close button. The image is clickable with a link.
Version: 2.0
Author: EasyToolsWP.com
*/

// Hook for admin menu
add_action('admin_menu', 'wc_popup_plugin_menu');

// Hook for adding styles and scripts on the frontend
add_action('wp_enqueue_scripts', 'wc_popup_plugin_enqueue_assets');

// Hook for displaying popups
add_action('wp_footer', 'wc_popup_plugin_display_popup');

// Enqueue styles and scripts
function wc_popup_plugin_enqueue_assets() {
    ?>
    <style>
        /* Overlay to dim the background */
        #wc-popup-overlay {
            position: fixed;
            top: 0;
            left: 0;
            width: 100vw;
            height: 100vh;
            background: rgba(0, 0, 0, 0.5);
            display: none;
            z-index: 9998;
            overflow: hidden;
        }

        /* Popup box styling */
        #wc-popup {
            position: fixed;
            top: 50%;
            left: 50%;
            transform: translate(-50%, -50%);
            width: 500px;
            background: #fff;
            padding: 20px;
            box-shadow: 0 0 10px rgba(0, 0, 0, 0.1);
            display: none;
            z-index: 9999;
            box-sizing: border-box;
            overflow: hidden; /* Prevent content from overflowing */
        }

        /* Close Button Styling */
        #wc-popup-close {
            position: absolute;
            top: 10px;
            right: 10px;
            font-size: 18px;
            cursor: pointer;
            font-weight: bold;
        }

        /* Flex container for Right and Left positioning */
        .wc-popup-content-right,
        .wc-popup-content-left {
            display: flex;
            justify-content: space-between;
            box-sizing: border-box;
            align-items: flex-start;
        }

        /* Right/Left: Text container takes 50%, Image takes 50% */
        .wc-popup-content-right div,
        .wc-popup-content-left div {
            flex: 0 0 50%;
            padding: 0 20px;
            box-sizing: border-box;
        }

        /* Right/Left: Image takes up exactly 50% of the container */
        .wc-popup-content-right img,
        .wc-popup-content-left img {
            flex: 0 0 50%;
            width: 100%; /* Set image width to 100% of its container */
            height: auto;
            object-fit: contain;
            display: block;
            box-sizing: border-box;
        }

        /* Flex container for Top and Bottom positioning */
        .wc-popup-content-top,
        .wc-popup-content-bottom {
            display: flex;
            flex-direction: column;
            justify-content: center;
            align-items: center;
            text-align: center;
        }

        /* Top/Bottom: Image takes up full width */
        .wc-popup-content-top img,
        .wc-popup-content-bottom img {
            width: 100%;
            max-width: 100%;
            height: auto;
        }

        /* Button Styling */
        .wc-popup-btn {
            padding: 10px 20px;
            background-color: #0073aa;
            color: white;
            text-decoration: none;
            border-radius: 5px;
            display: inline-block;
            margin-top: 10px;
        }

        /* Fix to prevent body from scrolling when popup is open */
        body.wc-popup-active {
            overflow: hidden;
        }

        /* Responsive styling for mobile */
        @media (max-width: 768px) {
            #wc-popup {
                width: 75%;
                padding: 15px;
            }
            .wc-popup-content-right,
            .wc-popup-content-left {
                flex-direction: column;
            }
            .wc-popup-content-right img,
            .wc-popup-content-left img {
                max-width: 100%;
                margin-bottom: 15px;
            }
            .wc-popup-content-right div,
            .wc-popup-content-left div {
                padding: 0;
            }
        }
    </style>
    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
    <script>
        jQuery(document).ready(function($) {
            // Show the popup and overlay after the delay
            $('.wc-popup').each(function() {
                var popup = $(this);
                var overlay = $('#wc-popup-overlay');
                var delay = popup.data('delay');
                var cookieKey = popup.data('cookie');
                var showOnce = popup.data('show-once');
                
                if (showOnce && document.cookie.indexOf(cookieKey) !== -1) {
                    return;
                }

                setTimeout(function() {
                    popup.fadeIn();
                    overlay.fadeIn();
                    $('body').addClass('wc-popup-active'); // Prevent scrolling
                }, delay);

                // Close popup when clicking on the close button
                $('#wc-popup-close', popup).on('click', function() {
                    popup.fadeOut();
                    overlay.fadeOut();
                    $('body').removeClass('wc-popup-active'); // Restore scrolling
                    if (showOnce) {
                        document.cookie = cookieKey + '=1; path=/';
                    }
                });

                // Close popup when clicking outside the popup
                overlay.on('click', function() {
                    popup.fadeOut();
                    overlay.fadeOut();
                    $('body').removeClass('wc-popup-active'); // Restore scrolling
                });
            });
        });
    </script>
    <?php
}

// Add admin menu page
add_action('admin_head', 'wc_popup_plugin_admin_assets');
function wc_popup_plugin_admin_assets() {
    ?>
    <style>
        .wc-popup-admin-section {
            background: #f9f9f9;
            padding: 20px;
            margin-bottom: 20px;
            border: 1px solid #ddd;
            border-radius: 5px;
        }
        .wc-popup-admin-section h2 {
            margin-top: 0;
            font-size: 18px;
        }
        .wc-popup-admin-section label {
            font-weight: bold;
            margin-top: 10px;
            display: block;
        }
        .wc-popup-admin-section input[type="text"],
        .wc-popup-admin-section textarea,
        .wc-popup-admin-section input[type="number"],
        .wc-popup-admin-section select {
            width: 100%;
            padding: 10px;
            margin-bottom: 10px;
            border: 1px solid #ccc;
            border-radius: 5px;
            font-size: 14px;
        }
        .wc-popup-admin-section input[type="checkbox"] {
            margin-right: 5px;
        }
        .wc-popup-admin-section input[type="submit"] {
            background-color: #0073aa;
            color: #fff;
            padding: 10px 20px;
            border: none;
            border-radius: 5px;
            cursor: pointer;
        }
        .wc-popup-admin-section input[type="submit"]:hover {
            background-color: #005b8a;
        }
    </style>
    <?php
}

function wc_popup_plugin_menu() {
    add_submenu_page(
        'woocommerce',
        'Popup Settings',
        'Popup Settings',
        'manage_options',
        'wc-popup-plugin-settings',
        'wc_popup_plugin_settings_page'
    );
}

function wc_popup_plugin_settings_page() {
    if (isset($_POST['wc_popup_save_settings'])) {
        $pages = ['frontpage', 'product', 'archive', 'cart', 'checkout'];
        foreach ($pages as $page) {
            update_option("wc_popup_{$page}_image", sanitize_text_field($_POST["wc_popup_{$page}_image"]));
            update_option("wc_popup_{$page}_text", sanitize_textarea_field($_POST["wc_popup_{$page}_text"]));
            update_option("wc_popup_{$page}_button_text", sanitize_text_field($_POST["wc_popup_{$page}_button_text"]));
            update_option("wc_popup_{$page}_url", sanitize_text_field($_POST["wc_popup_{$page}_url"]));
            update_option("wc_popup_{$page}_delay", intval($_POST["wc_popup_{$page}_delay"]));
            update_option("wc_popup_{$page}_position", sanitize_text_field($_POST["wc_popup_{$page}_position"]));
            update_option("wc_popup_{$page}_show_once", isset($_POST["wc_popup_{$page}_show_once"]) ? 'yes' : 'no');
            // Fix for checkbox: Save 'yes' if checked, 'no' if not checked
            update_option("wc_popup_{$page}_active", isset($_POST["wc_popup_{$page}_active"]) ? 'yes' : 'no');
            update_option("wc_popup_{$page}_heading", sanitize_text_field($_POST["wc_popup_{$page}_heading"]));
        }
        echo '<div class="notice notice-success is-dismissible"><p>Settings saved.</p></div>';
    }

    ?>
    <div class="wrap">
        <h1>Popup Settings</h1>
        <form method="post" action="">
            <?php
            $pages = [
                'frontpage' => 'Frontpage',
                'product' => 'Product Page',
                'archive' => 'Archive Page',
                'cart' => 'Cart Page',
                'checkout' => 'Checkout Page'
            ];
            foreach ($pages as $page => $label) {
                ?>
                <div class="wc-popup-admin-section">
                    <h2><?php echo $label; ?> Popup</h2>
                    <label for="wc_popup_<?php echo $page; ?>_active">
                        <input type="checkbox" id="wc_popup_<?php echo $page; ?>_active" name="wc_popup_<?php echo $page; ?>_active" <?php checked(get_option("wc_popup_{$page}_active"), 'yes'); ?> />
                        Activate Popup
                    </label>
                    <label for="wc_popup_<?php echo $page; ?>_image">Image URL:</label>
                    <input type="text" id="wc_popup_<?php echo $page; ?>_image" name="wc_popup_<?php echo $page; ?>_image" value="<?php echo esc_attr(get_option("wc_popup_{$page}_image")); ?>" />
                    
                    <label for="wc_popup_<?php echo $page; ?>_heading">Heading (H3):</label>
                    <input type="text" id="wc_popup_<?php echo $page; ?>_heading" name="wc_popup_<?php echo $page; ?>_heading" value="<?php echo esc_attr(get_option("wc_popup_{$page}_heading")); ?>" />
                    
                    <label for="wc_popup_<?php echo $page; ?>_text">Text:</label>
                    <textarea id="wc_popup_<?php echo $page; ?>_text" name="wc_popup_<?php echo $page; ?>_text"><?php echo esc_textarea(get_option("wc_popup_{$page}_text")); ?></textarea>
                    
                    <label for="wc_popup_<?php echo $page; ?>_button_text">Button Text:</label>
                    <input type="text" id="wc_popup_<?php echo $page; ?>_button_text" name="wc_popup_<?php echo $page; ?>_button_text" value="<?php echo esc_attr(get_option("wc_popup_{$page}_button_text")); ?>" />
                    
                    <label for="wc_popup_<?php echo $page; ?>_url">Link URL:</label>
                    <input type="text" id="wc_popup_<?php echo $page; ?>_url" name="wc_popup_<?php echo $page; ?>_url" value="<?php echo esc_attr(get_option("wc_popup_{$page}_url")); ?>" />
                    
                    <label for="wc_popup_<?php echo $page; ?>_delay">Popup Delay (ms):</label>
                    <input type="number" id="wc_popup_<?php echo $page; ?>_delay" name="wc_popup_<?php echo $page; ?>_delay" value="<?php echo esc_attr(get_option("wc_popup_{$page}_delay", 2000)); ?>" />
                    
                    <label for="wc_popup_<?php echo $page; ?>_position">Image Position:</label>
                    <select id="wc_popup_<?php echo $page; ?>_position" name="wc_popup_<?php echo $page; ?>_position">
                        <option value="top" <?php selected(get_option("wc_popup_{$page}_position"), 'top'); ?>>Top</option>
                        <option value="right" <?php selected(get_option("wc_popup_{$page}_position"), 'right'); ?>>Right</option>
                        <option value="bottom" <?php selected(get_option("wc_popup_{$page}_position"), 'bottom'); ?>>Bottom</option>
                        <option value="left" <?php selected(get_option("wc_popup_{$page}_position"), 'left'); ?>>Left</option>
                    </select>
                    
                    <label for="wc_popup_<?php echo $page; ?>_show_once">
                        <input type="checkbox" id="wc_popup_<?php echo $page; ?>_show_once" name="wc_popup_<?php echo $page; ?>_show_once" <?php checked(get_option("wc_popup_{$page}_show_once"), 'yes'); ?> />
                        Show Only Once
                    </label>
                </div>
                <?php
            }
            ?>
            <input type="submit" name="wc_popup_save_settings" value="Save Settings" class="button-primary" />
        </form>
    </div>
    <?php
}

function wc_popup_plugin_display_popup() {
    $pages = [
        'frontpage' => is_front_page(),
        'product' => is_product(),
        'archive' => is_shop() || is_product_category() || is_product_tag(),
        'cart' => is_cart(),
        'checkout' => is_checkout()
    ];

    foreach ($pages as $page => $condition) {
        // Check if popup is active
        if ($condition && get_option("wc_popup_{$page}_active") === 'yes') {
            $image = get_option("wc_popup_{$page}_image");
            $heading = get_option("wc_popup_{$page}_heading");
            $text = get_option("wc_popup_{$page}_text");
            $button_text = get_option("wc_popup_{$page}_button_text");
            $url = get_option("wc_popup_{$page}_url");
            $position = get_option("wc_popup_{$page}_position", 'top');
            $delay = get_option("wc_popup_{$page}_delay", 2000);
            $show_once = get_option("wc_popup_{$page}_show_once") === 'yes';
            $cookie_key = "wc_popup_{$page}_shown";
            $button_id = "wc-popup-btn-{$page}"; // Unique ID for each button

            // Only display if image, text, or button is present
            if ($image || $text || $button_text) {
                ?>
                <div id="wc-popup-overlay"></div> <!-- Overlay to close the popup when clicked -->
                <div id="wc-popup" class="wc-popup" data-delay="<?php echo esc_attr($delay); ?>" data-cookie="<?php echo esc_attr($cookie_key); ?>" data-show-once="<?php echo esc_attr($show_once); ?>">
                    <span id="wc-popup-close">X</span>
                    <div class="wc-popup-content-<?php echo esc_attr($position); ?>">
                        <?php if (($position === 'top' || $position === 'left') && $image): ?>
                            <a href="<?php echo esc_url($url); ?>"><img src="<?php echo esc_url($image); ?>" alt="Popup Image" /></a>
                        <?php endif; ?>
                        <div>
                            <?php if ($heading): ?>
                                <h3><?php echo esc_html($heading); ?></h3>
                            <?php endif; ?>
                            <?php if ($text): ?>
                                <p><a href="<?php echo esc_url($url); ?>"><?php echo esc_html($text); ?></a></p>
                            <?php endif; ?>
                            <?php if ($button_text): ?>
                                <a id="<?php echo esc_attr($button_id); ?>" href="<?php echo esc_url($url); ?>" class="wc-popup-btn"><?php echo esc_html($button_text); ?></a>
                            <?php endif; ?>
                        </div>
                        <?php if (($position === 'right' || $position === 'bottom') && $image): ?>
                            <a href="<?php echo esc_url($url); ?>"><img src="<?php echo esc_url($image); ?>" alt="Popup Image" /></a>
                        <?php endif; ?>
                    </div>
                </div>
                <?php
            }
        }
    }
}
?>
